==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/SummaryCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SummaryCellInfoDescription } from "./SummaryCellInfoDescription";
/**
 * @hidden
 */
var SummaryCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryCellInfoDescriptionMetadata, _super);
    function SummaryCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryCellInfoDescriptionMetadata.b = function (a) {
        if (SummaryCellInfoDescriptionMetadata.a == null) {
            SummaryCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryCellInfoDescriptionMetadata.c(SummaryCellInfoDescriptionMetadata.a);
        }
        if (a.k(SummaryCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.ab(SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ResolvedSummaryLabel", "String");
        a.item("ResolvedSummaryValue", "String");
        a.item("SummaryLabelTextColor", "Brush");
        a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:font/FontFamilyTransform)String");
        a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:font/FontSizeTransform)Number:double");
        a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:font/FontStyleTransform)String");
        a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:font/FontWeightTransform)String");
    };
    SummaryCellInfoDescriptionMetadata.d = function (a) {
        SummaryCellInfoDescriptionMetadata.b(a);
        a.ad("SummaryCellInfo", function () { return new SummaryCellInfoDescription(); });
        a.ac("SummaryCellInfo", SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.$t = markType(SummaryCellInfoDescriptionMetadata, 'SummaryCellInfoDescriptionMetadata');
    SummaryCellInfoDescriptionMetadata.a = null;
    return SummaryCellInfoDescriptionMetadata;
}(Base));
export { SummaryCellInfoDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/SummaryCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { SummaryCellInfoDescription } from "./SummaryCellInfoDescription";
/**
 * @hidden
 */
var SummaryCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SummaryCellInfoDescriptionMetadata, _super);
    function SummaryCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SummaryCellInfoDescriptionMetadata.b = function (a) {
        if (SummaryCellInfoDescriptionMetadata.a == null) {
            SummaryCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SummaryCellInfoDescriptionMetadata.c(SummaryCellInfoDescriptionMetadata.a);
        }
        if (a.k(SummaryCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.ac(SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("ResolvedSummaryLabel", "String");
        a.item("ResolvedSummaryValue", "String");
        a.item("SummaryLabelTextColor", "Brush");
        a.item("SummaryLabelFontFamily", "(w:SummaryLabelFontFamily/FontFamilyTransform,xam:SummaryLabelFontFamily,wf:SummaryLabelFontFamily,web:font/FontFamilyTransform)String");
        a.item("SummaryLabelFontSize", "(w:SummaryLabelFontSize,xam:SummaryLabelFontSize,wf:SummaryLabelFontSize,web:font/FontSizeTransform)Number:double");
        a.item("SummaryLabelFontStyle", "(w:SummaryLabelFontStyle/FontStyleTransform,xam:SummaryLabelFontFamily/FontStyleTransform,wf:SummaryLabelFontFamily/FontStyleTransform,web:font/FontStyleTransform)String");
        a.item("SummaryLabelFontWeight", "(w:SummaryLabelFontWeight/FontWeightTransform,xam:SummaryLabelFontFamily/FontWeightTransform,wf:SummaryLabelFontFamily/FontWeightTransform,web:font/FontWeightTransform)String");
    };
    SummaryCellInfoDescriptionMetadata.d = function (a) {
        SummaryCellInfoDescriptionMetadata.b(a);
        a.ae("SummaryCellInfo", function () { return new SummaryCellInfoDescription(); });
        a.ad("SummaryCellInfo", SummaryCellInfoDescriptionMetadata.a);
    };
    SummaryCellInfoDescriptionMetadata.$t = markType(SummaryCellInfoDescriptionMetadata, 'SummaryCellInfoDescriptionMetadata');
    SummaryCellInfoDescriptionMetadata.a = null;
    return SummaryCellInfoDescriptionMetadata;
}(Base));
export { SummaryCellInfoDescriptionMetadata };
